searchData={"content_type":"text/markdown","items":[{"doc":"Helps to manage roles and permissions directly on controllers/live_view with just a few config to implement\n\nThis library uses some concepts:\n\n- Action: basically it's just the name of the action that you want to run, a basic concept it's that  every `crud`\n  function it's an action\n- Permission Scope: it's the name of system area or whatever you want to define as a group of functions that you want\n  to lock with an action, a basic concept it's the controller it's an scope\n- Roles: it's the collection of scopes and actions that has the access schema of the user\n\nExample:\n\n```\n%{\n  user: %{\n    page: [:index, :show]\n  }\n}\n```","ref":"TrollBridge.html","title":"TrollBridge","type":"module"},{"doc":"`troll_bridge` directly helps to implement to your phoenix controller or live_view screens.\n\n#### Add the configuration\n\nYou need to create a module that uses the behaviour `TrollBridge.Behaviour`\n\n```elixir\n# troll_bridge_example/config/config.exs\nconfig :troll_bridge, config: TrollBridgeExample.TrollConfig\n\n# troll_bridge_example/lib/troll_bridge_example/troll_config.ex\ndefmodule TrollBridgeExample.TrollConfig do\n  @behaviour TrollBridge.Behaviour\n\n  @impl TrollBridge.Behaviour\n  def actions do\n    [:index, :show]\n  end\n\n  @impl TrollBridge.Behaviour\n  def scopes do\n    [:page, :page_alt]\n  end\n\n  @impl TrollBridge.Behaviour\n  def user_roles(_conn_or_socket) do\n    # here use the connection to get the session user and then from user get the assigned roles\n    [:user]\n  end\n\n  @impl TrollBridge.Behaviour\n  def user_permissions(_conn_or_socket) do\n    # here use the connection to get the session user and get the permissions of the assigned roles\n    %{page: [:index]}\n  end\n\nend\n```\n\n#### The implementation\n\n- Add `use TrollBridge.PhoenixController` or `use TrollBridge.LiveView`\n- Use the `permissions` macro to define a permission scope to the entire module (optional)\n- Add the module attribute `@action :index` to your function, you can specify the permission scope\n\n```elixir\ndefmodule TrollBridgeExampleWeb.PageController do\n  use TrollBridgeExampleWeb, :controller\n  use TrollBridge.PhoenixController\n\n  permissions(:page)\n\n  redirect_on_failure_url(\"/api/failure\")\n\n  @action :index\n  def index(conn, _params) do\n    conn\n    |> json(%{success: true, call: :index})\n  end\n\n  @action :show\n  def show(conn, _params) do\n    conn\n    |> json(%{success: true, call: :show})\n  end\n\n  @action page_alt: :show\n  def show_alt(conn, _params) do\n    conn\n    |> json(%{success: true, call: :show})\n  end\n\n  def failure(conn, _params) do\n    conn\n    |> json(%{forbidden: true})\n  end\nend\n```\n\n> The permission and the action must be defined on the scopes and actions on the implementation of  `TrollBridge.Behaviour`","ref":"TrollBridge.html#module-usage","title":"Usage; - TrollBridge","type":"module"},{"doc":"","ref":"TrollBridge.html#access_allowed?/2","title":"TrollBridge.access_allowed?/2","type":"function"},{"doc":"","ref":"TrollBridge.html#allowed?/3","title":"TrollBridge.allowed?/3","type":"function"},{"doc":"","ref":"TrollBridge.html#allowed_actions/0","title":"TrollBridge.allowed_actions/0","type":"function"},{"doc":"","ref":"TrollBridge.html#allowed_actions_string/0","title":"TrollBridge.allowed_actions_string/0","type":"function"},{"doc":"","ref":"TrollBridge.html#get_config/0","title":"TrollBridge.get_config/0","type":"function"},{"doc":"","ref":"TrollBridge.html#t:allowed_actions/0","title":"TrollBridge.allowed_actions/0","type":"type"},{"doc":"","ref":"TrollBridge.html#t:allowed_actions_string/0","title":"TrollBridge.allowed_actions_string/0","type":"type"},{"doc":"","ref":"TrollBridge.html#t:role_permissions/0","title":"TrollBridge.role_permissions/0","type":"type"},{"doc":"Behaviour that works to get the needed information from the project side to work correctly the validation","ref":"TrollBridge.Behaviour.html","title":"TrollBridge.Behaviour","type":"behaviour"},{"doc":"","ref":"TrollBridge.Behaviour.html#c:actions/0","title":"TrollBridge.Behaviour.actions/0","type":"callback"},{"doc":"","ref":"TrollBridge.Behaviour.html#c:scopes/0","title":"TrollBridge.Behaviour.scopes/0","type":"callback"},{"doc":"","ref":"TrollBridge.Behaviour.html#c:user_permissions/1","title":"TrollBridge.Behaviour.user_permissions/1","type":"callback"},{"doc":"","ref":"TrollBridge.Behaviour.html#c:user_roles/1","title":"TrollBridge.Behaviour.user_roles/1","type":"callback"},{"doc":"Implementation for Phoenix.LiveView to secure controller actions with troll_bridge","ref":"TrollBridge.LiveView.html","title":"TrollBridge.LiveView","type":"module"},{"doc":"Internal use modules, avoid use it","ref":"TrollBridge.Meta.FunctionLocker.html","title":"TrollBridge.Meta.FunctionLocker","type":"module"},{"doc":"Internal use modules, avoid use it","ref":"TrollBridge.Meta.PermissionScope.html","title":"TrollBridge.Meta.PermissionScope","type":"module"},{"doc":"","ref":"TrollBridge.Meta.PermissionScope.html#permissions/1","title":"TrollBridge.Meta.PermissionScope.permissions/1","type":"macro"},{"doc":"","ref":"TrollBridge.Meta.PermissionScope.html#redirect_on_failure_url/1","title":"TrollBridge.Meta.PermissionScope.redirect_on_failure_url/1","type":"macro"},{"doc":"","ref":"TrollBridge.Meta.PermissionScope.html#role/1","title":"TrollBridge.Meta.PermissionScope.role/1","type":"macro"},{"doc":"Implementation for Phoenix.Controller to secure controller actions with troll_bridge","ref":"TrollBridge.PhoenixController.html","title":"TrollBridge.PhoenixController","type":"module"},{"doc":"# TrollBridge\n\nHelps to manage roles and permissions directly on controllers/live_view with just a few config to implement\n\nThis library uses some concepts:\n\n- Action: basically it's just the name of the action that you want to run, a basic concept it's that  every `crud`\n  function it's an action\n- Permission Scope: it's the name of system area or whatever you want to define as a group of functions that you want\n  to lock with an action, a basic concept it's the controller it's an scope\n- Roles: it's the collection of scopes and actions that has the access schema of the user\n\nExample:\n\n  ```\n%{\n  user: %{\n    page: [:index, :show]\n  }\n}\n```\n\n- `user` is the name of the role\n- `page` is the scope\n- `index` and `show` are the defined actions","ref":"readme.html","title":"TrollBridge","type":"extras"},{"doc":"If [available in Hex](https://hexdocs.pm/troll_bridge), the package can be installed\nby adding `troll_bridge` to your list of dependencies in `mix.exs`:\n\n\n```elixir\ndef deps do\n  [\n    {:troll_bridge, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - TrollBridge","type":"extras"},{"doc":"`troll_bridge` directly helps to implement to your phoenix controller or live_view screens.\n\n#### Add the configuration\n\nYou need to create a module that uses the behaviour `TrollBridge.Behaviour` and add your implementation to get the right\ndata, like get the session user from database and load the roles and permissions from database\n\n```elixir\n# troll_bridge_example/config/config.exs\nconfig :troll_bridge, config: TrollBridgeExample.TrollConfig\n\n# troll_bridge_example/lib/troll_bridge_example/troll_config.ex\ndefmodule TrollBridgeExample.TrollConfig do\n  @behaviour TrollBridge.Behaviour\n    \n  @impl TrollBridge.Behaviour\n  def actions do\n    [:index, :show]\n  end\n    \n  @impl TrollBridge.Behaviour\n  def scopes do\n    [:page, :page_alt]\n  end\n    \n  @impl TrollBridge.Behaviour\n  def user_roles(_conn_or_socket) do\n    # here use the connection to get the session user and then from user get the assigned roles\n    [:user]\n  end\n    \n  @impl TrollBridge.Behaviour\n  def user_permissions(_conn_or_socket) do\n    # here use the connection to get the session user and get the permissions of the assigned roles\n    %{page: [:index]}\n  end\nend\n```\n\n\n#### The implementation\n\n- Add `use TrollBridge.PhoenixController` or `use TrollBridge.LiveView`\n- Use the `permissions` macro to define a permission scope to the entire module (optional)\n- Add the module attribute `@action :index` to your function, you can specify the permission scope\n\n```elixir\ndefmodule TrollBridgeExampleWeb.PageController do\n  use TrollBridgeExampleWeb, :controller\n  use TrollBridge.PhoenixController\n    \n  permissions(:page)\n    \n  redirect_on_failure_url(\"/api/failure\")\n    \n  @action :index\n  def index(conn, _params) do\n    conn\n    |> json(%{success: true, call: :index})\n  end\n    \n  @action :show\n  def show(conn, _params) do\n    conn\n    |> json(%{success: true, call: :show})\n  end\n    \n  @action page_alt: :show\n  def show_alt(conn, _params) do\n    conn\n    |> json(%{success: true, call: :show})\n  end\n    \n  def failure(conn, _params) do\n    conn\n    |> json(%{forbidden: true})\n  end\nend\n```\n\n> The permission and the action must be defined on the scopes and actions on the implementation of  `TrollBridge.Behaviour`","ref":"readme.html#usage","title":"Usage; - TrollBridge","type":"extras"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}